componenttools.all_are_components_in_same_parent
================================================

.. autofunction:: abjad.tools.componenttools.all_are_components_in_same_parent.all_are_components_in_same_parent
